==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/DateAfterModificationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.DateAfterModificationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Object to define the base blob action conditions. Properties daysAfterModificationGreaterThan, daysAfterLastAccessTimeGreaterThan and daysAfterCreationGreaterThan are mutually exclusive. The daysAfterLastTierChangeGreaterThan property is only applicable for tierToArchive actions which requires daysAfterModificationGreaterThan to be set, also it cannot be used in conjunction with daysAfterLastAccessTimeGreaterThan or daysAfterCreationGreaterThan.
 * @property daysAfterCreationGreaterThan Value indicating the age in days after blob creation.
 * @property daysAfterLastAccessTimeGreaterThan Value indicating the age in days after last blob access. This property can only be used in conjunction with last access time tracking policy
 * @property daysAfterLastTierChangeGreaterThan Value indicating the age in days after last blob tier change time. This property is only applicable for tierToArchive actions and requires daysAfterModificationGreaterThan to be set for baseBlobs based actions. The blob will be archived if both the conditions are satisfied.
 * @property daysAfterModificationGreaterThan Value indicating the age in days after last modification
 */
public data class DateAfterModificationArgs(
    public val daysAfterCreationGreaterThan: Output<Double>? = null,
    public val daysAfterLastAccessTimeGreaterThan: Output<Double>? = null,
    public val daysAfterLastTierChangeGreaterThan: Output<Double>? = null,
    public val daysAfterModificationGreaterThan: Output<Double>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.DateAfterModificationArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.DateAfterModificationArgs =
        com.pulumi.azurenative.storage.inputs.DateAfterModificationArgs.builder()
            .daysAfterCreationGreaterThan(daysAfterCreationGreaterThan?.applyValue({ args0 -> args0 }))
            .daysAfterLastAccessTimeGreaterThan(
                daysAfterLastAccessTimeGreaterThan?.applyValue({ args0 ->
                    args0
                }),
            )
            .daysAfterLastTierChangeGreaterThan(
                daysAfterLastTierChangeGreaterThan?.applyValue({ args0 ->
                    args0
                }),
            )
            .daysAfterModificationGreaterThan(
                daysAfterModificationGreaterThan?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [DateAfterModificationArgs].
 */
@PulumiTagMarker
public class DateAfterModificationArgsBuilder internal constructor() {
    private var daysAfterCreationGreaterThan: Output<Double>? = null

    private var daysAfterLastAccessTimeGreaterThan: Output<Double>? = null

    private var daysAfterLastTierChangeGreaterThan: Output<Double>? = null

    private var daysAfterModificationGreaterThan: Output<Double>? = null

    /**
     * @param value Value indicating the age in days after blob creation.
     */
    @JvmName("pshldvcccwemrbww")
    public suspend fun daysAfterCreationGreaterThan(`value`: Output<Double>) {
        this.daysAfterCreationGreaterThan = value
    }

    /**
     * @param value Value indicating the age in days after last blob access. This property can only be used in conjunction with last access time tracking policy
     */
    @JvmName("uckjxmmgpbocjcmu")
    public suspend fun daysAfterLastAccessTimeGreaterThan(`value`: Output<Double>) {
        this.daysAfterLastAccessTimeGreaterThan = value
    }

    /**
     * @param value Value indicating the age in days after last blob tier change time. This property is only applicable for tierToArchive actions and requires daysAfterModificationGreaterThan to be set for baseBlobs based actions. The blob will be archived if both the conditions are satisfied.
     */
    @JvmName("thjtqujoiwvsdwdb")
    public suspend fun daysAfterLastTierChangeGreaterThan(`value`: Output<Double>) {
        this.daysAfterLastTierChangeGreaterThan = value
    }

    /**
     * @param value Value indicating the age in days after last modification
     */
    @JvmName("qudkgfjurplmmobr")
    public suspend fun daysAfterModificationGreaterThan(`value`: Output<Double>) {
        this.daysAfterModificationGreaterThan = value
    }

    /**
     * @param value Value indicating the age in days after blob creation.
     */
    @JvmName("dginsqtptntgccyb")
    public suspend fun daysAfterCreationGreaterThan(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.daysAfterCreationGreaterThan = mapped
    }

    /**
     * @param value Value indicating the age in days after last blob access. This property can only be used in conjunction with last access time tracking policy
     */
    @JvmName("djexhjrlmlyvsrhj")
    public suspend fun daysAfterLastAccessTimeGreaterThan(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.daysAfterLastAccessTimeGreaterThan = mapped
    }

    /**
     * @param value Value indicating the age in days after last blob tier change time. This property is only applicable for tierToArchive actions and requires daysAfterModificationGreaterThan to be set for baseBlobs based actions. The blob will be archived if both the conditions are satisfied.
     */
    @JvmName("nmpmnjkyycdmguea")
    public suspend fun daysAfterLastTierChangeGreaterThan(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.daysAfterLastTierChangeGreaterThan = mapped
    }

    /**
     * @param value Value indicating the age in days after last modification
     */
    @JvmName("kmykjqunojdjhjit")
    public suspend fun daysAfterModificationGreaterThan(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.daysAfterModificationGreaterThan = mapped
    }

    internal fun build(): DateAfterModificationArgs = DateAfterModificationArgs(
        daysAfterCreationGreaterThan = daysAfterCreationGreaterThan,
        daysAfterLastAccessTimeGreaterThan = daysAfterLastAccessTimeGreaterThan,
        daysAfterLastTierChangeGreaterThan = daysAfterLastTierChangeGreaterThan,
        daysAfterModificationGreaterThan = daysAfterModificationGreaterThan,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/DateAfterModificationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.DateAfterModificationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Object to define the base blob action conditions. Properties daysAfterModificationGreaterThan, daysAfterLastAccessTimeGreaterThan and daysAfterCreationGreaterThan are mutually exclusive. The daysAfterLastTierChangeGreaterThan property is only applicable for tierToArchive actions which requires daysAfterModificationGreaterThan to be set, also it cannot be used in conjunction with daysAfterLastAccessTimeGreaterThan or daysAfterCreationGreaterThan.
 * @property daysAfterCreationGreaterThan Value indicating the age in days after blob creation.
 * @property daysAfterLastAccessTimeGreaterThan Value indicating the age in days after last blob access. This property can only be used in conjunction with last access time tracking policy
 * @property daysAfterLastTierChangeGreaterThan Value indicating the age in days after last blob tier change time. This property is only applicable for tierToArchive actions and requires daysAfterModificationGreaterThan to be set for baseBlobs based actions. The blob will be archived if both the conditions are satisfied.
 * @property daysAfterModificationGreaterThan Value indicating the age in days after last modification
 */
public data class DateAfterModificationArgs(
    public val daysAfterCreationGreaterThan: Output<Double>? = null,
    public val daysAfterLastAccessTimeGreaterThan: Output<Double>? = null,
    public val daysAfterLastTierChangeGreaterThan: Output<Double>? = null,
    public val daysAfterModificationGreaterThan: Output<Double>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.DateAfterModificationArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.DateAfterModificationArgs =
        com.pulumi.azurenative.storage.inputs.DateAfterModificationArgs.builder()
            .daysAfterCreationGreaterThan(daysAfterCreationGreaterThan?.applyValue({ args0 -> args0 }))
            .daysAfterLastAccessTimeGreaterThan(
                daysAfterLastAccessTimeGreaterThan?.applyValue({ args0 ->
                    args0
                }),
            )
            .daysAfterLastTierChangeGreaterThan(
                daysAfterLastTierChangeGreaterThan?.applyValue({ args0 ->
                    args0
                }),
            )
            .daysAfterModificationGreaterThan(
                daysAfterModificationGreaterThan?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [DateAfterModificationArgs].
 */
@PulumiTagMarker
public class DateAfterModificationArgsBuilder internal constructor() {
    private var daysAfterCreationGreaterThan: Output<Double>? = null

    private var daysAfterLastAccessTimeGreaterThan: Output<Double>? = null

    private var daysAfterLastTierChangeGreaterThan: Output<Double>? = null

    private var daysAfterModificationGreaterThan: Output<Double>? = null

    /**
     * @param value Value indicating the age in days after blob creation.
     */
    @JvmName("cpevsgryfqnovpte")
    public suspend fun daysAfterCreationGreaterThan(`value`: Output<Double>) {
        this.daysAfterCreationGreaterThan = value
    }

    /**
     * @param value Value indicating the age in days after last blob access. This property can only be used in conjunction with last access time tracking policy
     */
    @JvmName("qnomyoqpxnhpoopf")
    public suspend fun daysAfterLastAccessTimeGreaterThan(`value`: Output<Double>) {
        this.daysAfterLastAccessTimeGreaterThan = value
    }

    /**
     * @param value Value indicating the age in days after last blob tier change time. This property is only applicable for tierToArchive actions and requires daysAfterModificationGreaterThan to be set for baseBlobs based actions. The blob will be archived if both the conditions are satisfied.
     */
    @JvmName("kxnwpdqwamrfigne")
    public suspend fun daysAfterLastTierChangeGreaterThan(`value`: Output<Double>) {
        this.daysAfterLastTierChangeGreaterThan = value
    }

    /**
     * @param value Value indicating the age in days after last modification
     */
    @JvmName("bppmfothidtuejtk")
    public suspend fun daysAfterModificationGreaterThan(`value`: Output<Double>) {
        this.daysAfterModificationGreaterThan = value
    }

    /**
     * @param value Value indicating the age in days after blob creation.
     */
    @JvmName("inxjxthityyjskhr")
    public suspend fun daysAfterCreationGreaterThan(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.daysAfterCreationGreaterThan = mapped
    }

    /**
     * @param value Value indicating the age in days after last blob access. This property can only be used in conjunction with last access time tracking policy
     */
    @JvmName("bfnhgnklodbfuhrq")
    public suspend fun daysAfterLastAccessTimeGreaterThan(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.daysAfterLastAccessTimeGreaterThan = mapped
    }

    /**
     * @param value Value indicating the age in days after last blob tier change time. This property is only applicable for tierToArchive actions and requires daysAfterModificationGreaterThan to be set for baseBlobs based actions. The blob will be archived if both the conditions are satisfied.
     */
    @JvmName("fywfhjucmudhjgxk")
    public suspend fun daysAfterLastTierChangeGreaterThan(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.daysAfterLastTierChangeGreaterThan = mapped
    }

    /**
     * @param value Value indicating the age in days after last modification
     */
    @JvmName("wlgqncndijsrxlqk")
    public suspend fun daysAfterModificationGreaterThan(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.daysAfterModificationGreaterThan = mapped
    }

    internal fun build(): DateAfterModificationArgs = DateAfterModificationArgs(
        daysAfterCreationGreaterThan = daysAfterCreationGreaterThan,
        daysAfterLastAccessTimeGreaterThan = daysAfterLastAccessTimeGreaterThan,
        daysAfterLastTierChangeGreaterThan = daysAfterLastTierChangeGreaterThan,
        daysAfterModificationGreaterThan = daysAfterModificationGreaterThan,
    )
}
